@@ -28,32 +28,35 @@ from werkzeug.exceptions import RequestEntityTooLarge, UnsupportedMediaType
 
 from . import utils
 
-__version__ = '1.1'
+__version__ = '1.3'
 
 
-IMAGES = ('.jpg', '.jpeg', '.png', '.gif', '.bmp')
+IMAGES = ('.jpg', '.jpeg', '.png', '.gif', '.bmp',)
 
-AUDIO = ('.wav', '.mp3', '.aac', '.ogg', '.oga', '.flac')
+AUDIO = ('.wav', '.mp3', '.aac', '.ogg', '.oga', '.flac',)
+VIDEO = ('.mp4', '.mpg', '.avi', '.mkv',)
 
-DOCUMENTS = ('.pdf', '.rtf', '.txt',
+DOCUMENTS = ('.pdf', '.rtf', '.txt', '.md', '.mdown', '.rst',
     '.odf', '.odp', '.ods', '.odg', '.ott', '.otp', '.ots', '.otg',
     '.pages', '.key', '.numbers', '.gnumeric', '.abw',
     '.doc', '.ppt', '.xls', '.vsd',
     '.docx', '.pptx', '.xlsx', '.vsx',
     )
 
-DATA = ('.csv', '.json', '.xml', '.ini', '.plist', '.yaml', '.yml')
+DATA = ('.csv', '.json', '.xml', '.ini', '.plist', '.yaml', '.yml',)
 
-ARCHIVES = ('.zip', '.gz', '.bz2', '.tar', '.tgz', '.txz', '.7z')
+ARCHIVES = ('.zip', '.gz', '.bz2', '.tar', '.tgz', '.txz', '.7z',)
 
 DEFAULT = IMAGES + AUDIO + DOCUMENTS
 
+ALL = IMAGES + AUDIO + VIDEO + DOCUMENTS + DATA + ARCHIVES
+
 
 class FileStorage(object):
     
     def __init__(self, base_path, base_url='/static/media/',
-            upload_to='{yyyy}/{mm}/{dd}/', secret=False,
-            prefix='', allowed=DEFAULT, denied=None, max_size=None):
+            upload_to='{yyyy}/{mm}/{dd}/', secret=False, prefix='',
+            name=None, allowed=DEFAULT, denied=None, max_size=None):
         """
         Except for `base_path`, all of these parameters are optional,
         so only bother setting the ones relevant to your application.
@@ -96,6 +99,10 @@ class FileStorage(object):
             the same name at the same time. If `secret` is True, this
             will be ignored.
 
+        name
+        :   If set, it'll be used as the name of every uploaded file.
+            Instead of a string, this can also be a callable.
+
         allowed
         :   List of allowed file extensions. `None` to allow all
             of them. If the uploaded file doesn't have one of these
@@ -143,6 +150,7 @@ class FileStorage(object):
         self.upload_to = upload_to
         self.secret = secret
         self.prefix = prefix
+        self.name = name
         self.allowed = allowed or []
         self.denied = denied or []
         self.max_size = max_size
@@ -152,7 +160,7 @@ class FileStorage(object):
             self.upload_to, self.secret)
 
     def save(self, filesto, upload_to=None, secret=None, prefix=None,
-            allowed=None, denied=None, max_size=None):
+            name=None, allowed=None, denied=None, max_size=None):
         """
         Except for `filesto`, all of these parameters are optional, so only
         bother setting the ones relevant to *this upload*.
@@ -186,6 +194,10 @@ class FileStorage(object):
             the same name at the same time. If `secret` is True, this
             will be ignored.
 
+        name
+        :   If set, it'll be used as the name of every uploaded file.
+            Instead of a string, this can also be a callable.
+
         allowed
         :   List of allowed file extensions. `None` to allow all
             of them. If the uploaded file doesn't have one of these
@@ -227,6 +239,7 @@ class FileStorage(object):
         upload_to = upload_to or self.upload_to
         secret = secret or self.secret
         prefix = prefix or self.prefix
+        name = name or self.name
         original_filename = filesto.filename
         allowed = allowed or self.allowed
         denied = denied or self.denied
@@ -236,14 +249,16 @@ class FileStorage(object):
         tmplpath = upload_to
         if callable(tmplpath):
             tmplpath = tmplpath(original_filename)
-        name, ext = os.path.splitext(original_filename)
-        if secret:
-            name = utils.get_random_filename()
-        else:
-            name = prefix + name
-        filepath = utils.format_path(tmplpath, name)
+
+        oname, ext = os.path.splitext(original_filename)
+        if name:
+            new_name = name(original_filename) if callable(name) else name
+        else:    
+            new_name = utils.get_random_filename() if secret else prefix + oname
+
+        filepath = utils.format_path(tmplpath, new_name)
         
-        filename = utils.get_unique_filename(self.base_path, filepath, name,
+        filename = utils.get_unique_filename(self.base_path, filepath, new_name,
             ext=ext)
         fullpath = utils.make_dirs(self.base_path, filepath)
 
